==> nextcloud-19.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/theming/l10n/ja.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "プレビューを読み込み中...",
    "Saved" : "保存済み",
    "Admin" : "管理者",
    "a safe home for all your data" : "あなたのすべてのデータを安全に保管する場所",
    "Name cannot be empty" : "名前は空にできません",
    "The given name is too long" : "名前が長すぎます",
    "The given web address is too long" : "Webアドレスが長すぎます",
    "The given web address is not a valid URL" : "指定されたWebアドレスは有効なURLではありません",
    "The given legal notice address is too long" : "指定された法的通知アドレスが長すぎます",
    "The given legal notice address is not a valid URL" : "指定された法的通知アドレスは有効なURLではありません",
    "The given privacy policy address is too long" : "指定されたプライバシーポリシーのアドレスが長すぎます",
    "The given privacy policy address is not a valid URL" : "指定されたプライバシーポリシーアドレスは有効なURLではありません",
    "The given slogan is too long" : "スローガンが長すぎます",
    "The given color is invalid" : "無効な色です",
    "The file was uploaded" : "ファイルがアップロードされました",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "アップロードファイルサイズが、php.ini の upload_max_filesize を超過しています",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "アップロードファイルはHTMLフォームで指定された MAX_FILE_SIZE の制限を超えています",
    "The file was only partially uploaded" : "ファイルは一部分にしかアップロードされていません",
    "No file was uploaded" : "ファイルはアップロードされませんでした",
    "Missing a temporary folder" : "一時領域フォルダーがありません",
    "Could not write file to disk" : "ディスクにファイルを書き込めませんでした",
    "A PHP extension stopped the file upload" : "PHP拡張でファイルのアップロードが停止されています",
    "No file uploaded" : "ファイルがアップロードされていません",
    "Unsupported image type" : "サポートされていない画像形式です",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "あなたはすでにカスタムテーマを使用しています。 テーマ設定の設定が上書きされる可能性があります。",
    "Theming" : "テーマ",
    "Legal notice" : "法的通知",
    "Privacy policy" : "プライバシーポリシー",
    "Adjust the Nextcloud theme" : "Nextcloudテーマを調整する",
    "Open documentation" : "ドキュメントを開く",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "テーマでは、あなたのインスタンスとサポートされたクライアントのルック＆フィールを簡単に変更できます。この変更はすべてのユーザーが対象となります。",
    "Name" : "名前",
    "Reset to default" : "デフォルトに戻す",
    "Web link" : "Webリンク",
    "https://…" : "https://…",
    "Slogan" : "スローガン",
    "Color" : "色",
    "Logo" : "ロゴ",
    "Upload new logo" : "新しいロゴをアップロード",
    "Login image" : "ログイン画像",
    "Upload new login background" : "新しいログイン背景画像をアップロード",
    "Remove background image" : "背景画像を削除",
    "Advanced options" : "詳細オプション",
    "Legal notice link" : "法的通知のリンク",
    "Privacy policy link" : "プライバシーポリシーのリンク",
    "Header logo" : "ヘッダーロゴ",
    "Upload new header logo" : "新しいヘッダーロゴをアップロード",
    "Favicon" : "Favicon",
    "Upload new favicon" : "新しいfaviconをアップロード",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "アップロードしたロゴと色に基づいてfaviconを自動的に生成するには、SVG画像をサポートしているimagemagick PHP拡張をインストールしてください。"
},
"nplurals=1; plural=0;");

==> nextcloud-20.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/theming/l10n/ja.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "プレビューを読み込み中...",
    "Saved" : "保存済み",
    "Admin" : "管理者",
    "a safe home for all your data" : "あなたのすべてのデータを安全に保管する場所",
    "Name cannot be empty" : "名前は空にできません",
    "The given name is too long" : "名前が長すぎます",
    "The given web address is too long" : "Webアドレスが長すぎます",
    "The given web address is not a valid URL" : "指定されたWebアドレスは有効なURLではありません",
    "The given legal notice address is too long" : "指定された法的通知アドレスが長すぎます",
    "The given legal notice address is not a valid URL" : "指定された法的通知アドレスは有効なURLではありません",
    "The given privacy policy address is too long" : "指定されたプライバシーポリシーのアドレスが長すぎます",
    "The given privacy policy address is not a valid URL" : "指定されたプライバシーポリシーアドレスは有効なURLではありません",
    "The given slogan is too long" : "スローガンが長すぎます",
    "The given color is invalid" : "無効な色です",
    "The file was uploaded" : "ファイルがアップロードされました",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "アップロードファイルサイズが、php.ini の upload_max_filesize を超過しています",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "アップロードファイルはHTMLフォームで指定された MAX_FILE_SIZE の制限を超えています",
    "The file was only partially uploaded" : "ファイルは一部分にしかアップロードされていません",
    "No file was uploaded" : "ファイルはアップロードされませんでした",
    "Missing a temporary folder" : "一時領域フォルダーがありません",
    "Could not write file to disk" : "ディスクにファイルを書き込めませんでした",
    "A PHP extension stopped the file upload" : "PHP拡張でファイルのアップロードが停止されています",
    "No file uploaded" : "ファイルがアップロードされていません",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "あなたはすでにカスタムテーマを使用しています。 テーマ設定の設定が上書きされる可能性があります。",
    "Theming" : "テーマ",
    "Legal notice" : "法的通知",
    "Privacy policy" : "プライバシーポリシー",
    "Adjust the Nextcloud theme" : "Nextcloudテーマを調整する",
    "Open documentation" : "ドキュメントを開く",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "テーマでは、あなたのインスタンスとサポートされたクライアントのルック＆フィールを簡単に変更できます。この変更はすべてのユーザーが対象となります。",
    "Name" : "名前",
    "Reset to default" : "デフォルトに戻す",
    "Web link" : "Webリンク",
    "https://…" : "https://…",
    "Slogan" : "スローガン",
    "Color" : "色",
    "Logo" : "ロゴ",
    "Upload new logo" : "新しいロゴをアップロード",
    "Login image" : "ログイン画像",
    "Upload new login background" : "新しいログイン背景画像をアップロード",
    "Remove background image" : "背景画像を削除",
    "Advanced options" : "詳細オプション",
    "Legal notice link" : "法的通知のリンク",
    "Privacy policy link" : "プライバシーポリシーのリンク",
    "Header logo" : "ヘッダーロゴ",
    "Upload new header logo" : "新しいヘッダーロゴをアップロード",
    "Favicon" : "Favicon",
    "Upload new favicon" : "新しいfaviconをアップロード",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "アップロードしたロゴと色に基づいてfaviconを自動的に生成するには、SVG画像をサポートしているimagemagick PHP拡張をインストールしてください。",
    "Unsupported image type" : "サポートされていない画像形式です"
},
"nplurals=1; plural=0;");
